@@ -13,10 +13,16 @@ insDoc(aux1, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
 insDoc(aux1, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
 insDoc(aux1, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
 insDoc(aux1, gLnk("R", "AnimationSampling", "vars/Utilities.html#AnimationSampling"))
+insDoc(aux1, gLnk("R", "AOLoewdin", "vars/Hamiltonian.html#AOLoewdin"))
+insDoc(aux1, gLnk("R", "AONormalize", "vars/Hamiltonian.html#AONormalize"))
+insDoc(aux1, gLnk("R", "AOSubmeshForPeriodic", "vars/Hamiltonian.html#AOSubmeshForPeriodic"))
+insDoc(aux1, gLnk("R", "AOThreshold", "vars/Hamiltonian.html#AOThreshold"))
+insDoc(aux1, gLnk("R", "AOTruncation", "vars/Hamiltonian.html#AOTruncation"))
 insDoc(aux1, gLnk("R", "ArpackInitialTolerance", "vars/SCF.html#ArpackInitialTolerance"))
 insDoc(aux1, gLnk("R", "AtomsMagnetDirection", "vars/SCF.html#AtomsMagnetDirection"))
 insDoc(aux1, gLnk("R", "AxisType", "vars/Utilities.html#AxisType"))
 aux1 = insFld(aux0, gFld("B", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "BandStructureComputeProjections", "vars/Output.html#BandStructureComputeProjections"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_CalcDipoleMtxels", "vars/Output.html#BerkeleyGW_CalcDipoleMtxels"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_CalcExchange", "vars/Output.html#BerkeleyGW_CalcExchange"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_NumberBands", "vars/Output.html#BerkeleyGW_NumberBands"))
@@ -46,6 +52,7 @@ insDoc(aux1, gLnk("R", "CasidaHermitianConjugate", "vars/Linear_Response.html#Ca
 insDoc(aux1, gLnk("R", "CasidaKohnShamStates", "vars/Linear_Response.html#CasidaKohnShamStates"))
 insDoc(aux1, gLnk("R", "CasidaKSEnergyWindow", "vars/Linear_Response.html#CasidaKSEnergyWindow"))
 insDoc(aux1, gLnk("R", "CasidaMomentumTransfer", "vars/Linear_Response.html#CasidaMomentumTransfer"))
+insDoc(aux1, gLnk("R", "CasidaPrintExcitations", "vars/Linear_Response.html#CasidaPrintExcitations"))
 insDoc(aux1, gLnk("R", "CasidaQuadratureOrder", "vars/Linear_Response.html#CasidaQuadratureOrder"))
 insDoc(aux1, gLnk("R", "CasidaSpectrumBroadening", "vars/Utilities.html#CasidaSpectrumBroadening"))
 insDoc(aux1, gLnk("R", "CasidaSpectrumEnergyStep", "vars/Utilities.html#CasidaSpectrumEnergyStep"))
@@ -54,6 +61,7 @@ insDoc(aux1, gLnk("R", "CasidaSpectrumMinEnergy", "vars/Utilities.html#CasidaSpe
 insDoc(aux1, gLnk("R", "CasidaSpectrumRotationMatrix", "vars/Utilities.html#CasidaSpectrumRotationMatrix"))
 insDoc(aux1, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
 insDoc(aux1, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
+insDoc(aux1, gLnk("R", "CasidaWeightThreshold", "vars/Linear_Response.html#CasidaWeightThreshold"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
 insDoc(aux1, gLnk("R", "ComplexScaling", "vars/Hamiltonian.html#ComplexScaling"))
 insDoc(aux1, gLnk("R", "ComplexScalingAlpha", "vars/Hamiltonian.html#ComplexScalingAlpha"))
@@ -110,9 +118,11 @@ insDoc(aux1, gLnk("R", "DensitytoCalc", "vars/States.html#DensitytoCalc"))
 insDoc(aux1, gLnk("R", "DerivativesOrder", "vars/Mesh.html#DerivativesOrder"))
 insDoc(aux1, gLnk("R", "DerivativesStencil", "vars/Mesh.html#DerivativesStencil"))
 insDoc(aux1, gLnk("R", "DescribeParticlesModelmb", "vars/States.html#DescribeParticlesModelmb"))
+insDoc(aux1, gLnk("R", "DFTULevel", "vars/Hamiltonian.html#DFTULevel"))
 insDoc(aux1, gLnk("R", "Dimensions", "vars/System.html#Dimensions"))
 insDoc(aux1, gLnk("R", "DisableOpenCL", "vars/Execution.html#DisableOpenCL"))
 insDoc(aux1, gLnk("R", "Displacement", "vars/Linear_Response.html#Displacement"))
+insDoc(aux1, gLnk("R", "DOSComputePDOS", "vars/Output.html#DOSComputePDOS"))
 insDoc(aux1, gLnk("R", "DOSEnergyMax", "vars/Output.html#DOSEnergyMax"))
 insDoc(aux1, gLnk("R", "DOSEnergyMin", "vars/Output.html#DOSEnergyMin"))
 insDoc(aux1, gLnk("R", "DOSEnergyPoints", "vars/Output.html#DOSEnergyPoints"))
@@ -130,6 +140,7 @@ insDoc(aux1, gLnk("R", "EigensolverMaxIter", "vars/SCF.html#EigensolverMaxIter")
 insDoc(aux1, gLnk("R", "EigensolverMinimizationIter", "vars/SCF.html#EigensolverMinimizationIter"))
 insDoc(aux1, gLnk("R", "EigensolverParpack", "vars/SCF.html#EigensolverParpack"))
 insDoc(aux1, gLnk("R", "EigensolverSaveMemory", "vars/SCF.html#EigensolverSaveMemory"))
+insDoc(aux1, gLnk("R", "EigensolverSkipKpoints", "vars/SCF.html#EigensolverSkipKpoints"))
 insDoc(aux1, gLnk("R", "EigensolverTolerance", "vars/SCF.html#EigensolverTolerance"))
 insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
 insDoc(aux1, gLnk("R", "EMCalcBornCharges", "vars/Linear_Response.html#EMCalcBornCharges"))
@@ -153,6 +164,7 @@ insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
 insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
 insDoc(aux1, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
 insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
+insDoc(aux1, gLnk("R", "ExtraStatesToConverge", "vars/States.html#ExtraStatesToConverge"))
 aux1 = insFld(aux0, gFld("F", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "FeastContour", "vars/SCF.html#FeastContour"))
 insDoc(aux1, gLnk("R", "FeastMaxIter", "vars/SCF.html#FeastMaxIter"))
@@ -172,6 +184,7 @@ insDoc(aux1, gLnk("R", "GaugeFieldDynamics", "vars/Hamiltonian.html#GaugeFieldDy
 insDoc(aux1, gLnk("R", "GaugeFieldPropagate", "vars/Hamiltonian.html#GaugeFieldPropagate"))
 insDoc(aux1, gLnk("R", "GaugeVectorField", "vars/Hamiltonian.html#GaugeVectorField"))
 insDoc(aux1, gLnk("R", "GOCenter", "vars/Calculation_Modes.html#GOCenter"))
+insDoc(aux1, gLnk("R", "GOConstrains", "vars/Calculation_Modes.html#GOConstrains"))
 insDoc(aux1, gLnk("R", "GOFireIntegrator", "vars/Calculation_Modes.html#GOFireIntegrator"))
 insDoc(aux1, gLnk("R", "GOFireMass", "vars/Calculation_Modes.html#GOFireMass"))
 insDoc(aux1, gLnk("R", "GOLineTol", "vars/Calculation_Modes.html#GOLineTol"))
@@ -184,6 +197,7 @@ insDoc(aux1, gLnk("R", "GOTolerance", "vars/Calculation_Modes.html#GOTolerance")
 insDoc(aux1, gLnk("R", "GuessMagnetDensity", "vars/SCF.html#GuessMagnetDensity"))
 insDoc(aux1, gLnk("R", "GyromagneticRatio", "vars/Hamiltonian.html#GyromagneticRatio"))
 aux1 = insFld(aux0, gFld("H", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "HamiltonianApplyPacked", "vars/Execution.html#HamiltonianApplyPacked"))
 insDoc(aux1, gLnk("R", "HamiltonianVariation", "vars/Linear_Response.html#HamiltonianVariation"))
 aux1 = insFld(aux0, gFld("I", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "IgnoreExternalIons", "vars/Hamiltonian.html#IgnoreExternalIons"))
@@ -358,12 +372,13 @@ insDoc(aux1, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
 insDoc(aux1, gLnk("R", "OperateOpenCL", "vars/Execution.html#OperateOpenCL"))
 insDoc(aux1, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
 insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
-insDoc(aux1, gLnk("R", "OutputBandsGnuplotMode", "vars/Output.html#OutputBandsGnuplotMode"))
-insDoc(aux1, gLnk("R", "OutputBandsGraceMode", "vars/Output.html#OutputBandsGraceMode"))
+insDoc(aux1, gLnk("R", "Output_KPT", "vars/Output.html#Output_KPT"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
 insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
+insDoc(aux1, gLnk("R", "OutputGradientPotential", "vars/Output.html#OutputGradientPotential"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
+insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
 insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
@@ -381,19 +396,31 @@ insDoc(aux1, gLnk("R", "PCMCalcMethod", "vars/Hamiltonian.html#PCMCalcMethod"))
 insDoc(aux1, gLnk("R", "PCMCalculation", "vars/Hamiltonian.html#PCMCalculation"))
 insDoc(aux1, gLnk("R", "PCMCavity", "vars/Hamiltonian.html#PCMCavity"))
 insDoc(aux1, gLnk("R", "PCMChargeSmearNN", "vars/Hamiltonian.html#PCMChargeSmearNN"))
+insDoc(aux1, gLnk("R", "PCMDebyeRelaxTime", "vars/Hamiltonian.html#PCMDebyeRelaxTime"))
+insDoc(aux1, gLnk("R", "PCMDrudeLDamping", "vars/Hamiltonian.html#PCMDrudeLDamping"))
+insDoc(aux1, gLnk("R", "PCMDrudeLOmega", "vars/Hamiltonian.html#PCMDrudeLOmega"))
 insDoc(aux1, gLnk("R", "PCMDynamicEpsilon", "vars/Hamiltonian.html#PCMDynamicEpsilon"))
+insDoc(aux1, gLnk("R", "PCMEoM", "vars/Hamiltonian.html#PCMEoM"))
+insDoc(aux1, gLnk("R", "PCMEoMInitialCharges", "vars/Hamiltonian.html#PCMEoMInitialCharges"))
+insDoc(aux1, gLnk("R", "PCMEpsilonModel", "vars/Hamiltonian.html#PCMEpsilonModel"))
 insDoc(aux1, gLnk("R", "PCMGamessBenchmark", "vars/Hamiltonian.html#PCMGamessBenchmark"))
+insDoc(aux1, gLnk("R", "PCMKick", "vars/Hamiltonian.html#PCMKick"))
+insDoc(aux1, gLnk("R", "PCMLocalField", "vars/Hamiltonian.html#PCMLocalField"))
+insDoc(aux1, gLnk("R", "PCMNonequilibrium", "vars/Hamiltonian.html#PCMNonequilibrium"))
 insDoc(aux1, gLnk("R", "PCMQtotTol", "vars/Hamiltonian.html#PCMQtotTol"))
 insDoc(aux1, gLnk("R", "PCMRadiusScaling", "vars/Hamiltonian.html#PCMRadiusScaling"))
 insDoc(aux1, gLnk("R", "PCMRenormCharges", "vars/Hamiltonian.html#PCMRenormCharges"))
 insDoc(aux1, gLnk("R", "PCMSmearingFactor", "vars/Hamiltonian.html#PCMSmearingFactor"))
+insDoc(aux1, gLnk("R", "PCMSolute", "vars/Hamiltonian.html#PCMSolute"))
 insDoc(aux1, gLnk("R", "PCMSpheresOnH", "vars/Hamiltonian.html#PCMSpheresOnH"))
 insDoc(aux1, gLnk("R", "PCMStaticEpsilon", "vars/Hamiltonian.html#PCMStaticEpsilon"))
+insDoc(aux1, gLnk("R", "PCMTessMinDistance", "vars/Hamiltonian.html#PCMTessMinDistance"))
 insDoc(aux1, gLnk("R", "PCMTessSubdivider", "vars/Hamiltonian.html#PCMTessSubdivider"))
 insDoc(aux1, gLnk("R", "PCMUpdateIter", "vars/Hamiltonian.html#PCMUpdateIter"))
 insDoc(aux1, gLnk("R", "PCMVdWRadii", "vars/Hamiltonian.html#PCMVdWRadii"))
 insDoc(aux1, gLnk("R", "PDBClassical", "vars/System.html#PDBClassical"))
 insDoc(aux1, gLnk("R", "PDBCoordinates", "vars/System.html#PDBCoordinates"))
+insDoc(aux1, gLnk("R", "PDBGOConstrains", "vars/Calculation_Modes.html#PDBGOConstrains"))
 insDoc(aux1, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
 insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
 insDoc(aux1, gLnk("R", "PES_Flux_ARPES_grid", "vars/Time-Dependent.html#PES_Flux_ARPES_grid"))
@@ -501,6 +528,7 @@ insDoc(aux1, gLnk("R", "SCFCalculatePartialCharges", "vars/SCF.html#SCFCalculate
 insDoc(aux1, gLnk("R", "SCFCalculateStress", "vars/SCF.html#SCFCalculateStress"))
 insDoc(aux1, gLnk("R", "SCFinLCAO", "vars/SCF.html#SCFinLCAO"))
 insDoc(aux1, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
+insDoc(aux1, gLnk("R", "SkipSOrbitals", "vars/Hamiltonian.html#SkipSOrbitals"))
 insDoc(aux1, gLnk("R", "Smearing", "vars/States.html#Smearing"))
 insDoc(aux1, gLnk("R", "SmearingFunction", "vars/States.html#SmearingFunction"))
 insDoc(aux1, gLnk("R", "SmearingMPOrder", "vars/States.html#SmearingMPOrder"))
@@ -551,8 +579,10 @@ insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalF
 insDoc(aux1, gLnk("R", "TDFloquetDimension", "vars/Time-Dependent.html#TDFloquetDimension"))
 insDoc(aux1, gLnk("R", "TDFloquetFrequency", "vars/Time-Dependent.html#TDFloquetFrequency"))
 insDoc(aux1, gLnk("R", "TDFloquetSample", "vars/Time-Dependent.html#TDFloquetSample"))
+insDoc(aux1, gLnk("R", "TDFreezeDFTUOccupations", "vars/Time-Dependent.html#TDFreezeDFTUOccupations"))
 insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
 insDoc(aux1, gLnk("R", "TDFreezeOrbitals", "vars/Time-Dependent.html#TDFreezeOrbitals"))
+insDoc(aux1, gLnk("R", "TDFreezeU", "vars/Time-Dependent.html#TDFreezeU"))
 insDoc(aux1, gLnk("R", "TDFunctions", "vars/Time-Dependent.html#TDFunctions"))
 insDoc(aux1, gLnk("R", "TDGlobalForce", "vars/Time-Dependent.html#TDGlobalForce"))
 insDoc(aux1, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTimeScale"))
@@ -563,6 +593,7 @@ insDoc(aux1, gLnk("R", "TDMomentumTransfer", "vars/Time-Dependent.html#TDMomentu
 insDoc(aux1, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleLmax"))
 insDoc(aux1, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
 insDoc(aux1, gLnk("R", "TDOutputComputeInterval", "vars/Time-Dependent.html#TDOutputComputeInterval"))
+insDoc(aux1, gLnk("R", "TDOutputDFTU", "vars/Time-Dependent.html#TDOutputDFTU"))
 insDoc(aux1, gLnk("R", "TDPolarization", "vars/Time-Dependent.html#TDPolarization"))
 insDoc(aux1, gLnk("R", "TDPolarizationDirection", "vars/Time-Dependent.html#TDPolarizationDirection"))
 insDoc(aux1, gLnk("R", "TDPolarizationEquivAxes", "vars/Time-Dependent.html#TDPolarizationEquivAxes"))
@@ -594,10 +625,12 @@ insDoc(aux1, gLnk("R", "Units", "vars/Execution.html#Units"))
 insDoc(aux1, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
 insDoc(aux1, gLnk("R", "UnitsXYZFiles", "vars/Execution.html#UnitsXYZFiles"))
 insDoc(aux1, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
+insDoc(aux1, gLnk("R", "UseAllAtomicOrbitals", "vars/Hamiltonian.html#UseAllAtomicOrbitals"))
 insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
 insDoc(aux1, gLnk("R", "UserDefinedStates", "vars/States.html#UserDefinedStates"))
 aux1 = insFld(aux0, gFld("V", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
+insDoc(aux1, gLnk("R", "VDWD3Functional", "vars/Hamiltonian.html#VDWD3Functional"))
 insDoc(aux1, gLnk("R", "vdWNPoints", "vars/Linear_Response.html#vdWNPoints"))
 insDoc(aux1, gLnk("R", "VDWSelfConsistent", "vars/Hamiltonian.html#VDWSelfConsistent"))
 insDoc(aux1, gLnk("R", "Velocities", "vars/System.html#Velocities"))
@@ -623,6 +656,8 @@ insDoc(aux1, gLnk("R", "XCUseGaugeIndependentKED", "vars/Hamiltonian.html#XCUseG
 insDoc(aux1, gLnk("R", "Xlength", "vars/Mesh.html#Xlength"))
 insDoc(aux1, gLnk("R", "XSFCoordinates", "vars/System.html#XSFCoordinates"))
 insDoc(aux1, gLnk("R", "XSFCoordinatesAnimStep", "vars/System.html#XSFCoordinatesAnimStep"))
+insDoc(aux1, gLnk("R", "XSFGOConstrains", "vars/Calculation_Modes.html#XSFGOConstrains"))
 insDoc(aux1, gLnk("R", "XSFVelocities", "vars/System.html#XSFVelocities"))
 insDoc(aux1, gLnk("R", "XYZCoordinates", "vars/System.html#XYZCoordinates"))
+insDoc(aux1, gLnk("R", "XYZGOConstrains", "vars/Calculation_Modes.html#XYZGOConstrains"))
 insDoc(aux1, gLnk("R", "XYZVelocities", "vars/System.html#XYZVelocities"))
