@@ -16,7 +16,6 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: cl_global.h 2146 2006-05-23 17:36:00Z xavier $
 */
 
 #ifndef __CL_GLOBAL_H__
@@ -30,6 +29,10 @@
 //#pragma OPENCL EXTENSION cl_amd_printf:enable
 #endif
 
+#ifdef CUDA
+#include <cuda_compat.h>
+#endif
+
 #endif
 
 /*
