@@ -16,7 +16,6 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: oct_gsl_f.c 12543 2014-10-13 19:53:11Z dstrubbe $
 */
 
 #include <config.h>
@@ -237,125 +236,6 @@ double FC_FUNC_(oct_ran_flat, OCT_RAN_FLAT)
   return gsl_ran_flat(*r, *a, *b);
 }
 
-
-/* Interpolation */
-void FC_FUNC_(oct_spline_end, OCT_SPLINE_END)
-     (void **spl, void **acc)
-{
-  gsl_spline_free((gsl_spline *)(*spl));
-  gsl_interp_accel_free((gsl_interp_accel *)(*acc));
-}
-
-void FC_FUNC_(oct_spline_fit, OCT_SPLINE_FIT)
-		 (const fint *nrc, const double *x, const double *y, void **spl, void **acc)
-{
-  /* the GSL headers actually specify size_t instead of const int for nrc */
-  *acc = (void *)gsl_interp_accel_alloc();
-  *spl = (void *)gsl_spline_alloc(gsl_interp_cspline, *nrc);	
-  gsl_spline_init((gsl_spline *)(*spl), x, y, *nrc);
-  fflush(stdout);
-}
-
-double FC_FUNC_(oct_spline_eval, OCT_SPLINE_EVAL)
-     (const double *x, const void **spl, void **acc)
-{
-  /* the GSL headers specify double x instead of const double x */
-  return gsl_spline_eval((gsl_spline *)(*spl), *x, (gsl_interp_accel *)(*acc));
-}
-
-
-void FC_FUNC_(oct_spline_eval_array, OCT_SPLINE_EVAL_ARRAY)
-     (const fint * nn, double *xf, const void **spl, void **acc)
-{
-  int ii;
-  for(ii = 0; ii < *nn; ii++){
-    xf[ii] = gsl_spline_eval((gsl_spline *)(*spl), xf[ii], (gsl_interp_accel *)(*acc));
-  }
-}
-
-void FC_FUNC_(oct_spline_eval_array4, OCT_SPLINE_EVAL_ARRAY4)
-     (const fint * nn, float *xf, const void **spl, void **acc)
-{
-  int ii;
-  for(ii = 0; ii < *nn; ii++){
-    xf[ii] = (float) gsl_spline_eval((gsl_spline *)(*spl), (double) xf[ii], (gsl_interp_accel *)(*acc));
-  }
-}
-
-/* use a stride of 2 to store into just the real part of a Fortran complex array */
-void FC_FUNC_(oct_spline_eval_arrayz, OCT_SPLINE_EVAL_ARRAYZ)
-     (const fint * nn, double *xf, const void **spl, void **acc)
-{
-  int ii;
-  for(ii = 0; ii < *nn; ii++){
-    xf[ii*2] = gsl_spline_eval((gsl_spline *)(*spl), xf[ii*2], (gsl_interp_accel *)(*acc));
-  }
-}
-
-/* use a stride of 2 to store into just the real part of a Fortran complex array */
-void FC_FUNC_(oct_spline_eval_arrayc, OCT_SPLINE_EVAL_ARRAYC)
-     (const fint * nn, float *xf, const void **spl, void **acc)
-{
-  int ii;
-  for(ii = 0; ii < *nn; ii++){
-    xf[ii*2] = (float) gsl_spline_eval((gsl_spline *)(*spl), (double) xf[ii*2], (gsl_interp_accel *)(*acc));
-  }
-}
-
-/* This function returns the number of points with which a spline
-	 was constructed (the size component of the gsl_spline struct). */
-fint FC_FUNC_(oct_spline_npoints, OCT_SPLINE_NPOINTS)
-     (const void **spl)
-{
-  return (fint)((gsl_spline *)(*spl))->size;
-}
-
-/* This function places in the x array the x values of a given spline spl*/ 
-void FC_FUNC_(oct_spline_x, OCT_SPLINE_X)
-     (const void **spl, double *x)
-{
-  int size, i;
-	
-  size = (int)((gsl_spline *)(*spl))->size;
-  for(i=0; i<size; i++)
-    x[i] = ((gsl_spline *)(*spl))->x[i];
-}
-
-/* This function places in the y array the y values of a given spline spl*/ 
-void FC_FUNC_(oct_spline_y, OCT_SPLINE_Y)
-     (const void **spl, double *y)
-{
-  int size, i;
-	
-  size = (int)((gsl_spline *)(*spl))->size;
-  for(i=0; i<size; i++)
-    y[i] = ((gsl_spline *)(*spl))->y[i];
-}
-
-/* Returns the integral of the spline stored in spl, between a and b */
-double FC_FUNC_(oct_spline_eval_integ, OCT_SPLINE_EVAL_INTEG)
-     (const void **spl, const double *a, const double *b, void **acc)
-{
-  /* the GSL headers specify double a, double b */
-  return gsl_spline_eval_integ((gsl_spline *)(*spl), *a, *b, (gsl_interp_accel *)(* acc));
-}
-
-/* Performs the derivative of a spline */
-double FC_FUNC_(oct_spline_eval_der, OCT_SPLINE_EVAL_DER)
-     (const double *x, const void **spl, void **acc)
-{
-  /* the GSL headers specify double x */
-  return gsl_spline_eval_deriv((gsl_spline *)(*spl), *x, (gsl_interp_accel *)(*acc));
-}
-
-/* Performs the second derivative of a spline */
-double FC_FUNC_(oct_spline_eval_der2, OCT_SPLINE_EVAL_DER2)
-     (const double *x, const void **spl, void **acc)
-{
-  /* the GSL headers specify double x */
-  return gsl_spline_eval_deriv2((gsl_spline *)(*spl), *x, (gsl_interp_accel *)(*acc));
-}
-
 void FC_FUNC_(oct_strerror, OCT_STRERROR)
      (const fint *err, STR_F_TYPE res STR_ARG1)
 {
